@@ -174,8 +174,8 @@ obj_earthsat (Now *np, Obj *op)
 	/* find geocentric EOD equatorial directly from xyz vector */
 	dtmp = atan2 (SatY, SatX);
 	range (&dtmp, 2*PI);
-	op->s_gaera = (float) dtmp;
-	op->s_gaedec = (float) atan2 (SatZ, sqrt(SatX*SatX + SatY*SatY));
+	op->s_gaera = dtmp;
+	op->s_gaedec = atan2 (SatZ, sqrt(SatX*SatX + SatY*SatY));
 
 	/* find topocentric from site location */
 	GetSitPosition(SiteLat,SiteLong,SiteAltitude,CrntTime,
@@ -244,10 +244,15 @@ obj_earthsat (Now *np, Obj *op)
 	    ra = op->s_gaera;
 	    dec = op->s_gaedec;
 	}
-	if (epoch != EOD)
+	if (epoch != EOD && mjd != epoch)
 	    precess (mjd, epoch, &ra, &dec);
-	op->s_ra = (float)ra;
-	op->s_dec = (float)dec;
+	op->s_ra = ra;
+	op->s_dec = dec;
+
+	/* Since nutation and aberration not relevant for a satellite,
+	   we store the same RA and dec in its "astrometric" fields */
+	op->s_astrora = ra;
+	op->s_astrodec = dec;
 
 	/* just make up a size and brightness */
 	set_smag (op, ESAT_MAG);
