@@ -1302,6 +1302,21 @@ static int Body_obj_cir(Body *body, char *fieldname, unsigned topocentric)
 
 static int Body_riset_cir(Body *body, char *fieldname)
 {
+     /* This warning was added in November 2007; to ensure more than
+        six months of warning, the rise/set attributes themselves
+        should therefore not be removed until July of 2008. */
+     static char *warning =
+          "the ephem.Body attributes 'rise_time', 'rise_az',"
+          " 'transit_time', 'transit_alt', 'set_time', 'set_az',"
+          " 'circumpolar', and 'never_up' are deprecated;"
+          " please convert your program to use the ephem.Observer"
+          " functions next_rising(), previous_rising(), next_transit(),"
+          " and so forth\n";
+     static int warned_already = 0;
+     if (!warned_already) {
+          if (PyErr_Warn(PyExc_DeprecationWarning, warning)) return -1;
+          warned_already = 1;
+     }
      if ((body->obj.o_flags & VALID_RISET) == 0) {
 	  if (body->obj.o_flags == 0) {
 	       PyErr_Format(PyExc_RuntimeError, "field %s undefined"
@@ -1824,7 +1839,7 @@ static PyMemberDef EarthSatellite_members[] = {
 static PyTypeObject BodyType = {
      PyObject_HEAD_INIT(NULL)
      0,
-     "_libastro.Body",
+     "ephem.Body",
      sizeof(Body),
      0,
      Body_dealloc,		/* tp_dealloc */
@@ -1867,7 +1882,7 @@ static PyTypeObject BodyType = {
 static PyTypeObject PlanetType = {
      PyObject_HEAD_INIT(NULL)
      0,
-     "_libastro.Planet",
+     "ephem.Planet",
      sizeof(Planet),
      0,
      0,				/* tp_dealloc */
@@ -1910,7 +1925,7 @@ static PyTypeObject PlanetType = {
 static PyTypeObject PlanetMoonType = {
      PyObject_HEAD_INIT(NULL)
      0,
-     "_libastro.PlanetMoon",
+     "ephem.PlanetMoon",
      sizeof(PlanetMoon),
      0,
      Body_dealloc,		/* tp_dealloc */
@@ -1953,7 +1968,7 @@ static PyTypeObject PlanetMoonType = {
 static PyTypeObject SaturnType = {
      PyObject_HEAD_INIT(NULL)
      0,
-     "_libastro.Saturn",
+     "ephem.Saturn",
      sizeof(Saturn),
      0,
      0,				/* tp_dealloc */
@@ -1996,7 +2011,7 @@ static PyTypeObject SaturnType = {
 static PyTypeObject MoonType = {
      PyObject_HEAD_INIT(NULL)
      0,
-     "_libastro.Moon",
+     "ephem.Moon",
      sizeof(Moon),
      0,
      0,				/* tp_dealloc */
@@ -2039,7 +2054,7 @@ static PyTypeObject MoonType = {
 static PyTypeObject FixedBodyType = {
      PyObject_HEAD_INIT(NULL)
      0,
-     "_libastro.FixedBody",
+     "ephem.FixedBody",
      sizeof(FixedBody),
      0,
      0,				/* tp_dealloc */
@@ -2082,7 +2097,7 @@ static PyTypeObject FixedBodyType = {
 static PyTypeObject BinaryStarType = {
      PyObject_HEAD_INIT(NULL)
      0,
-     "_libastro.BinaryStar",
+     "ephem.BinaryStar",
      sizeof(BinaryStar),
      0,
      0,				/* tp_dealloc */
@@ -2125,7 +2140,7 @@ static PyTypeObject BinaryStarType = {
 static PyTypeObject EllipticalBodyType = {
      PyObject_HEAD_INIT(NULL)
      0,
-     "_libastro.EllipticalBody",
+     "ephem.EllipticalBody",
      sizeof(EllipticalBody),
      0,
      0,				/* tp_dealloc */
@@ -2168,7 +2183,7 @@ static PyTypeObject EllipticalBodyType = {
 static PyTypeObject HyperbolicBodyType = {
      PyObject_HEAD_INIT(NULL)
      0,
-     "_libastro.HyperbolicBody",
+     "ephem.HyperbolicBody",
      sizeof(HyperbolicBody),
      0,
      0,				/* tp_dealloc */
@@ -2211,7 +2226,7 @@ static PyTypeObject HyperbolicBodyType = {
 static PyTypeObject ParabolicBodyType = {
      PyObject_HEAD_INIT(NULL)
      0,
-     "_libastro.ParabolicBody",
+     "ephem.ParabolicBody",
      sizeof(ParabolicBody),
      0,
      0,				/* tp_dealloc */
@@ -2254,7 +2269,7 @@ static PyTypeObject ParabolicBodyType = {
 static PyTypeObject EarthSatelliteType = {
      PyObject_HEAD_INIT(NULL)
      0,
-     "_libastro.EarthSatellite",
+     "ephem.EarthSatellite",
      sizeof(EarthSatellite),
      0,
      0,				/* tp_dealloc */
@@ -2645,6 +2660,21 @@ static PyObject *moon_phases(PyObject *self, PyObject *args)
      return o;
 }
 
+static PyObject *my_eq_ecl(PyObject *self, PyObject *args)
+{
+     PyObject *o = 0;
+     double mjd, ra, dec, lg, lt;
+     if (!PyArg_ParseTuple(args, "Odd:eq_ecl", &o, &ra, &dec)) return 0;
+     if (!o)
+	  mjd = mjd_now();
+     else if (PyObject_IsInstance(o, (PyObject*) &ObserverType))
+	  mjd = ((Observer*) o)->now.n_mjd;
+     else if (parse_mjd(o, &mjd) == -1)
+	  return 0;
+     eq_ecl(mjd, ra, dec, &lt, &lg);
+     return Py_BuildValue("(dd)", lg, lt);
+}
+
 /*
  * The global methods table and the module initialization function.
  */
@@ -2681,6 +2711,8 @@ static PyMethodDef libastro_methods[] = {
       " Universal Time."},
      {"moon_phases", (PyCFunction) moon_phases, METH_VARARGS,
       "compute the new and full moons nearest a given date"},
+     {"eq_ecl", (PyCFunction) my_eq_ecl, METH_VARARGS,
+      "compute the ecliptic longitude and latitude of an RA and dec"},
 
      {"builtin_planets", (PyCFunction) builtin_planets, METH_NOARGS,
       "return the list of built-in planet objects"},
